@@ -33,13 +33,13 @@
 #' }
 #' @seealso \code{SDADcv}, \code{\link{SDAAP}} and \code{\link{SDAP}}
 #' @keywords internal
-SDAD <- function (x, ...) UseMethod("SDAD")
+SDAD <- function (Xt, ...) UseMethod("SDAD")
 
 #' @return \code{NULL}
 #'
 #' @rdname SDAD
 #' @method SDAD default
-SDAD.default <- function(Xt, Yt, Om, gam, lam, mu, q, PGsteps, PGtol, maxits, tol, selector = rep(1,dim(Xt)[2]), initTheta){
+SDAD.default <- function(Xt, Yt, Om, gam, lam, mu, q, PGsteps, PGtol, maxits, tol, selector = rep(1,dim(Xt)[2]), initTheta, ...){
   # TODO: Handle Yt as a factor and generate dummy matrix from it
 
   ###
