@@ -72,13 +72,13 @@
 #' This function might require a wrapper similar to ASDA.
 #' @rdname SZVDcv
 #' @export SZVDcv
-SZVDcv <- function(Atrain, ...) UseMethod("SZVDcv",Atrain)
+SZVDcv <- function(Atrain, ...) UseMethod("SZVDcv", Atrain)
 
 #' @return \code{NULL}
-#'
+#' @export
 #' @rdname SZVDcv
 #' @method SZVDcv default
-SZVDcv.default <- function(Atrain, Aval, k, num_gammas, g_mults, D, sparsity_pen, scaling, penalty, beta, tol, ztol, maxits, quiet){
+SZVDcv.default <- function(Atrain, Aval, k, num_gammas, g_mults, D, sparsity_pen, scaling, penalty, beta, tol, ztol, maxits, quiet, ...){
   # Get dimensions of the training set.
   N = dim(Atrain)[1]
   p = dim(Atrain)[2]-1
